@@ -17,12 +17,13 @@ instanceMethods = [
 # accessors
 def tableRelationship(self, sourceClassName, relationshipName, destinationClassName, primaryKeyName, primaryKeyType, inverseName = None):
     sourceTableName = jinja2Extensions.underscore(sourceClassName)
-    destinationTableName = jinja2Extensions.underscore(relationshipName)
+    destinationTableName = jinja2Extensions.underscore(destinationClassName)
+    relationshipTableName = '%s_%s' % (sourceTableName, relationshipName)
 
     backReference = self.backref(inverseName) if inverseName else None
 
     relationshipTable = self.Table(
-        '%s_%s' % (sourceTableName, destinationTableName),
+        relationshipTableName ,
         self.Column(sourceTableName, primaryKeyType, self.ForeignKey('%s.%s' % (sourceTableName, primaryKeyName))),
         self.Column(destinationTableName, primaryKeyType, self.ForeignKey('%s.%s' % (destinationTableName, primaryKeyName)))
     )
